@@ -12,7 +12,6 @@
 #include <QColor>
 #include <QDBusPendingCallWatcher>
 #include <QPointer>
-#include <QScopedPointer>
 
 #include <KSharedConfig>
 
@@ -43,8 +42,8 @@ class KCMColors : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(ColorsSettings *colorsSettings READ colorsSettings CONSTANT)
     Q_PROPERTY(bool downloadingFile READ downloadingFile NOTIFY downloadingFileChanged)
     Q_PROPERTY(QColor accentColor READ accentColor WRITE setAccentColor NOTIFY accentColorChanged)
-    Q_PROPERTY(bool applyAccentColorFromWallpaper READ applyAccentColorFromWallpaper WRITE setApplyAccentColorFromWallpaper NOTIFY
-                   applyAccentColorFromWallpaperChanged)
+    Q_PROPERTY(QColor lastUsedCustomAccentColor READ lastUsedCustomAccentColor WRITE setLastUsedCustomAccentColor NOTIFY lastUsedCustomAccentColorChanged)
+    Q_PROPERTY(bool accentColorFromWallpaper READ accentColorFromWallpaper WRITE setAccentColorFromWallpaper NOTIFY accentColorFromWallpaperChanged)
 
 public:
     KCMColors(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
@@ -69,10 +68,14 @@ public:
     void setAccentColor(const QColor &accentColor);
     void resetAccentColor();
     Q_SIGNAL void accentColorChanged();
-    Q_SIGNAL void applyAccentColorFromWallpaperChanged();
 
-    bool applyAccentColorFromWallpaper() const;
-    void setApplyAccentColorFromWallpaper(bool boolean);
+    QColor lastUsedCustomAccentColor() const;
+    void setLastUsedCustomAccentColor(const QColor &accentColor);
+    Q_SIGNAL void lastUsedCustomAccentColorChanged();
+
+    bool accentColorFromWallpaper() const;
+    void setAccentColorFromWallpaper(bool boolean);
+    Q_SIGNAL void accentColorFromWallpaperChanged();
 
     Q_INVOKABLE void installSchemeFromFile(const QUrl &url);
 
@@ -80,10 +83,9 @@ public:
 
     // we take an extraneous reference to the accent colour here in order to have the bindings
     // re-evaluate when it changes
-    Q_INVOKABLE QColor tinted(const QColor& color, const QColor& accent, bool tints, qreal tintFactor);
+    Q_INVOKABLE QColor tinted(const QColor &color, const QColor &accent, bool tints, qreal tintFactor);
     Q_INVOKABLE QColor accentBackground(const QColor &accent, const QColor &background);
     Q_INVOKABLE QColor accentForeground(const QColor &accent, const bool &isActive);
-    Q_INVOKABLE void applyWallpaperAccentColor();
 
 public Q_SLOTS:
     void load() override;
@@ -106,6 +108,8 @@ private:
     void saveColors();
     void processPendingDeletions();
 
+    void applyWallpaperAccentColor();
+
     void installSchemeFile(const QString &path);
 
     ColorsModel *m_model;
@@ -120,6 +124,6 @@ private:
     KSharedConfigPtr m_config;
     KConfigWatcher::Ptr m_configWatcher;
 
-    QScopedPointer<QTemporaryFile> m_tempInstallFile;
+    std::unique_ptr<QTemporaryFile> m_tempInstallFile;
     QPointer<KIO::FileCopyJob> m_tempCopyJob;
 };
