@@ -47,34 +47,57 @@ void SlideFilterModel::setSourceModel(QAbstractItemModel *sourceModel)
 {
     if (this->sourceModel()) {
         disconnect(this->sourceModel(), nullptr, this, nullptr);
-    }
-    QSortFilterProxyModel::setSourceModel(sourceModel);
-    if (m_SortingMode == SortingMode::Random && !m_usedInConfig) {
-        buildRandomOrder();
+        // If the new model and the old model is the same model, QSortFilterProxyModel will not invalidate the filter
+        QSortFilterProxyModel::setSourceModel(nullptr);
     }
     if (sourceModel) {
         connect(sourceModel, &QAbstractItemModel::modelReset, this, &SlideFilterModel::buildRandomOrder);
-        connect(sourceModel, &QAbstractItemModel::rowsInserted, this, [this] {
+        connect(sourceModel, &QAbstractItemModel::rowsInserted, this, [this](const QModelIndex &, int first, int last) {
             if (m_SortingMode != SortingMode::Random || m_usedInConfig) {
                 return;
             }
             const int old_count = m_randomOrder.size();
+            if (first < old_count /* Not appended to end */) {
+                // Increase the existing row numbers that >= first to make space for new items
+                for (auto &row : m_randomOrder) {
+                    if (row >= first) {
+                        row += last - first + 1;
+                    }
+                }
+            }
+            // Then append new row numbers
             m_randomOrder.resize(this->sourceModel()->rowCount());
-            std::iota(m_randomOrder.begin() + old_count, m_randomOrder.end(), old_count);
-            std::shuffle(m_randomOrder.begin() + old_count, m_randomOrder.end(), m_random);
+            std::iota(std::next(m_randomOrder.begin(), old_count), m_randomOrder.end(), first); // first to last
+            std::shuffle(std::next(m_randomOrder.begin(), old_count), m_randomOrder.end(), m_random);
         });
-        connect(sourceModel, &QAbstractItemModel::rowsRemoved, this, [this] {
+        connect(sourceModel, &QAbstractItemModel::rowsRemoved, this, [this](const QModelIndex &, int first, int last) {
             if (m_SortingMode != SortingMode::Random || m_usedInConfig) {
                 return;
             }
+
+            const int old_count = m_randomOrder.size();
             m_randomOrder.erase(std::remove_if(m_randomOrder.begin(),
                                                m_randomOrder.end(),
-                                               [this](const int v) {
-                                                   return v >= this->sourceModel()->rowCount();
+                                               [first, last](int v) {
+                                                   return v >= first && v <= last;
                                                }),
                                 m_randomOrder.end());
+
+            if (last + 1 < old_count /* Not the last one */) {
+                // Decrease the remaining row numbers that > last
+                for (auto &row : m_randomOrder) {
+                    if (row > last) {
+                        row -= last - first + 1;
+                    }
+                }
+            }
         });
     }
+    // Update random order before QSortFilterProxyModel sorts
+    QSortFilterProxyModel::setSourceModel(sourceModel);
+    if (m_SortingMode == SortingMode::Random && !m_usedInConfig) {
+        buildRandomOrder();
+    }
 }
 
 bool SlideFilterModel::lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const
@@ -153,6 +176,7 @@ void SlideFilterModel::setSortingMode(SortingMode::Mode slideshowMode, bool slid
         buildRandomOrder();
     }
     QSortFilterProxyModel::invalidate();
+    sort(0);
 }
 
 void SlideFilterModel::invalidate()
